"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
var Request = /** @class */ (function () {
    function Request(config) {
        if (config === void 0) { config = {}; }
        var _this = this;
        this.interceptorAttempts = 0;
        this.service = axios_1.default.create();
        this.config = config;
        this.service.defaults.withCredentials = this.config.withCredentials;
        this.service.defaults.headers.common['X-Requested-With'] = 'XMLHttpRequest';
        if (this.config.headers) {
            var headers_1 = this.config.headers;
            Object.keys(headers_1).forEach(function (key) {
                _this.service.defaults.headers.common[key] = headers_1[key];
            });
        }
        this.service.interceptors.response.use(function (response) {
            var _a;
            (_a = _this.config.successCallbacks) === null || _a === void 0 ? void 0 : _a.forEach(function (callback) {
                callback(response);
            });
            _this.interceptorAttempts = 0;
            return response;
        }, function (error) {
            var _a, _b;
            if (!error.response) {
                return Promise.reject(error);
            }
            var responseStatusCode = error.response.status;
            if (_this.config.interceptor) {
                var interceptorResult = _this.config.interceptor(error.response, _this.service, _this.interceptorAttempts);
                _this.interceptorAttempts += 1;
                if (interceptorResult !== false) {
                    return interceptorResult;
                }
            }
            (_b = (_a = _this.config.errorCallbacks) === null || _a === void 0 ? void 0 : _a.find(function (callback) {
                if (callback.errorCode === null) {
                    return true;
                }
                var callbackErrorCode = callback.errorCode;
                if (!Array.isArray(callbackErrorCode)) {
                    callbackErrorCode = [callbackErrorCode];
                }
                return callbackErrorCode.includes(responseStatusCode);
            })) === null || _b === void 0 ? void 0 : _b.callback(error);
            return Promise.reject(error);
        });
    }
    Request.getInstance = function () {
        if (!Request.instance) {
            Request.instance = new Request(Request.instanceConfig);
        }
        return Request.instance;
    };
    Request.setConfig = function (config) {
        Object.keys(config).forEach(function (key) {
            // @ts-ignore
            Request.instanceConfig[key] = config[key];
        });
    };
    Request.setHeader = function (name, value) {
        var config = Request.getInstance().getConfig();
        if (config.headers) {
            config.headers[name] = value;
        }
        Request.instance = new Request(config);
    };
    Request.prototype.getConfig = function () {
        return this.config;
    };
    // eslint-disable-next-line max-len
    Request.prototype.get = function (url, config) {
        return this.service.get(url, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.post = function (url, data, config) {
        return this.service.post(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.patch = function (url, data, config) {
        return this.service.patch(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.put = function (url, data, config) {
        return this.service.put(url, data, config);
    };
    // eslint-disable-next-line max-len
    Request.prototype.delete = function (url, config) {
        return this.service.delete(url, config);
    };
    Request.instanceConfig = {
        errorCallbacks: [],
        successCallbacks: [],
        headers: {},
        withCredentials: true,
    };
    return Request;
}());
exports.default = Request;
//# sourceMappingURL=Request.js.map